@@ -38,7 +38,7 @@ documentation of the distribution modules to get more informations about all pos
 
 =head1 MOTIVATION
 
-My motivation is very simple. Every linux administrator knows the well-known tool sar of sysstat.
+My motivation is very simple... every linux administrator knows the well-known tool sar of sysstat.
 It helps me a lot of time to search for system bottlenecks and to solve problems, but it's hard to
 parse the output if you want to store the statistics into a database. So I thought to develope
 Sys::Statistics::Linux. It's not a replacement but it should make it simpler to you to write your
@@ -49,22 +49,26 @@ If Sys::Statistics::Linux doesn't provide statistics that are strongly needed th
 =head1 TECHNICAL NOTE
 
 This distribution collects statistics by the virtual F</proc> filesystem (procfs) and is
-developed on the default vanilla kernel. It is tested on x86 hardware with the distributions RHEL,
-Fedora, Debian, Ubuntu, Asianux, Slackware, Mandriva, SuSE (SuSE on s390 and s390x architecture
-as well but a long time ago) and openSUSE on kernel versions 2.4 and/or 2.6. It's possible that
-it doesn't run on all linux distributions if some procfs features are deactivated or too much
-modified. As example the linux kernel 2.4 can compiled with the option C<CONFIG_BLK_STATS> what
-turn on or off block statistics for devices.
+developed on the default vanilla kernel. It is tested on x86 hardware with the distributions
+RHEL, Fedora, Debian, Ubuntu, Asianux, Slackware, Mandriva and openSuSE (SLES on zSeries as
+well but a long time ago) on kernel versions 2.4 and/or 2.6. It's possible that it doesn't
+run on all linux distributions if some procfs features are deactivated or too much modified.
+As example the linux kernel 2.4 can compiled with the option C<CONFIG_BLK_STATS> what turn
+on or off block statistics for devices.
+
+Don't give up if some of the modules doesn't run on your hardware! Tell me what's wrong
+and I will try to solve it! You just have to make the first move and to send me a mail. :-)
 
 =head1 DELTAS
 
 The statistics for C<CpuStats>, C<ProcStats>, C<PgSwStats>, C<NetStats>, C<DiskStats> and C<Processes>
 are deltas, for this reason it's necessary to initialize the statistics before the data can be
 prepared by C<get()>. These statistics can be initialized with the methods C<new()>, C<set()> and
-C<init()>. Any option that is set to 1 will be initialized by the call of C<new()> or C<set()>.
-The call of init() re-initialize all statistics that are set to 1 or 2. By the call of C<get()>
-the initial statistics will be updated automatically. Please refer the section L</METHODS> to get more
-information about the calls of C<new()>, C<set()>, C<init()> and C<get()>.
+C<init()>. For any option that is set to 1, the statistics will be initialized by the call of
+C<new()> or C<set()>. The call of init() re-initialize all statistics that are set to 1 or 2.
+By the call of C<get()> the initial statistics will be updated automatically. Please refer the
+section L</METHODS> to get more informations about the usage of C<new()>, C<set()>, C<init()>
+and C<get()>.
 
 Another exigence is to sleep for a while - at least for one second - before the call of C<get()>
 if you want to get useful statistics. The statistics for C<SysInfo>, C<MemStats>, C<SockStats>,
@@ -76,7 +80,9 @@ L<Sys::Statistics::Linux::Compilation> object. The inital statistics will be upd
 
 =head1 MANUAL PROC(5)
 
-The L<<a href="http://www.kernel.org/doc/man-pages/online/pages/man5/proc.5.html">Linux Programmer's Manual</a>>.
+The Linux Programmer's Manual
+
+    http://www.kernel.org/doc/man-pages/online/pages/man5/proc.5.html
 
 =head1 OPTIONS
 
@@ -191,6 +197,7 @@ The following example would calculate average statistics for 30 minutes:
 
     # initiate cpustats
     my $lxs = Sys::Statistics::Linux->new( cpustats => 1 );
+    sleep(1);
 
     while ( 1 ) {
         sleep(1800);
@@ -198,16 +205,32 @@ The following example would calculate average statistics for 30 minutes:
     }
 
 If you just want a current snapshot of the system each 30 minutes and not the average
-the following example would be better for you:
+then the following example would be better for you:
 
-    # don't initiate cpustats
+    # do not initiate cpustats
     my $lxs = Sys::Statistics::Linux->new( cpustats => 2 );
 
     while ( 1 ) {
-        sleep(1800);
-        $lxs->init;
+        $lxs->init;             # init the statistics
+        sleep(1);               # sleep for the deltas
+        my $stat = $lxs->get;   # get the statistics
+        sleep(1800);            # sleep until the next run
+    }
+
+If you want to write a simple command line utility that prints the current workload
+to the screen then you can use something like this:
+
+    my @order = qw(user system iowait idle nice irq softirq total);
+    printf "%-20s%8s%8s%8s%8s%8s%8s%8s%8s\n", 'time', @order;
+
+    my $lxs = Sys::Statistics::Linux->new( cpustats => 1 );
+
+    while ( 1 ){
         sleep(1);
-        my $stat = $lxs->get;
+        my $cpu  = $lxs->get->cpustats;
+        my $time = $lxs->gettime;
+        printf "%-20s%8s%8s%8s%8s%8s%8s%8s%8s\n",
+            $time, @{$cpu->{cpu}}{@order};
     }
 
 =head2 settime()
@@ -229,7 +252,7 @@ automatically. You can also set a time format with C<gettime()>.
 
 Or
 
-    my ($date, $time) = $lxs->gettime;
+    my ($date, $time) = $lxs->gettime();
 
 Or
 
@@ -266,7 +289,7 @@ Set and get a time stamp:
     $lxs->settime('%Y/%m/%d %H:%M:%S');
     print $lxs->gettime, "\n";
 
-If you want to know how the data looks like you can use C<Data::Dumper> to check it:
+If you want to know how the data structure looks like you can use C<Data::Dumper> to check it:
 
     use strict;
     use warnings;
@@ -292,7 +315,7 @@ How to get the top 5 processes with the highest cpu workload:
 
 =head1 BACKWARD COMPATIBILITY
 
-The old options and keys - CpuStats, NetStats, etc - are still available together but deprecated!
+The old options and keys - CpuStats, NetStats, etc - are still available but deprecated!
 It's not possible to access the statistics via L<Sys::Statistics::Linux::Compilation> and it's
 not possible to call C<search()> and C<psfind()> if you use the old options.
 
@@ -300,7 +323,7 @@ You should use the new options and access the statistics over the accessors
 
     $stats->cpustats
 
-or direct
+or directly with
 
     $stats->{cpustats}
 
@@ -338,7 +361,7 @@ This program is free software; you can redistribute it and/or modify it under th
 =cut
 
 package Sys::Statistics::Linux;
-our $VERSION = '0.35_01';
+our $VERSION = '0.39_01';
 
 use strict;
 use warnings;
@@ -445,7 +468,7 @@ sub get {
         if ($self->{opts}->{$opt}) {
             $stat{$opt} = $self->{obj}->{$opt}->get();
             if ($opt eq 'netstats') {
-                $stat{netinfo} = $stat{$opt} = $self->{obj}->{$opt}->get_raw();
+                $stat{netinfo} = $self->{obj}->{$opt}->get_raw();
             }
         }
     }
